==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/controllers/zpracovanadochazka.php <==
<?php
/**
 * stanislav.elbl, 21.04.2016
 */

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\BlockViewObject;
use Ron\MVC\JsonController;
use Ron\MVC\JsonOutputObject;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\RonPortal\XML\RonPortalXMLForm;
use Ron\TextManager;
use RonPortal\Dochazka\MesicniVysledkyBrowser;
use RonPortal\Dochazka\MesicniVysledkyBrowser1;
use RonPortal\Dochazka\PrirazeniKalendare;
use RonPortal\Dochazka\Smena;
use RonPortal\Kapacity\KapacityUtils;
use RonPortal\Kapacity\PlanovaniKapacit_PlanovanaSmena;
use RonPortal\Kapacity\PlanovaniKapacitRecord;
use RonPortal\NastaveniUzivatele;
use RonPortal\NeniPravoException;
use RonPortal\Obdobi;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\System\AgentManager;
use RonPortal\System\ReportOutputObject;

class ZpracovanaDochazkaController extends JsonController
{
    const SETTINGS_ZOBRAZIT_MESICNI = 'mesicnivezpracovane'; // priznak, jestli se maji ve zpracovane zobrazit mesicni vysledky (standardni zobrazeni jako v mesicnich vysledcich)

    /** @var Database */
    public $database;

    /**
     * ZpracovanaDochazkaController constructor.
     * @param $database
     */
    public function __construct($database)
    {
        $this->database = $database;
    }


    /**
     * @param ZpracovanaDochazkaBrowser $b
     * @return string
     */
    function zobrazZpracovanou($b)
    {
        Model::addViewObject($b);

        if ($b ->denniVysledky ->pp  &&  RonPortalSettings::getIntValue(self::SETTINGS_ZOBRAZIT_MESICNI) ) {
            // zobrazi standardni needitovatelne mesicni vysledky
            if (RonPortalSettings::getIntValue(RonPortalSettings::MESICNI_VYSLEDKY_ZOBRAZIT)  &&  RonPortalSettings::getValue(RonPortalSettings::MESICNI_VYSLEDKY_RADKY)) {
                $b_mv = new MesicniVysledkyBrowser($this ->database, false);
                $b_mv ->tableId = 'zpracovanadochazka_mv';
                $b_mv ->showFilter = false;
                $b_mv ->filterForm = $b ->filterForm; // pro nacteni parametru (obdobi, pp)
                $b_mv ->load();
                Model::addViewObject($b_mv);
            } else {
                $v = new BlockViewObject();
                $v ->wrappingElementParams = 'id="zpracovanadochazka_mv"';

                $b_mv = new MesicniVysledkyBrowser1($this ->database);
                $b_mv ->showFilter = false;
                $b_mv ->filterForm = $b ->filterForm; // pro nacteni parametru (obdobi, pp)
                $b_mv ->load();

                $v ->addViewObject($b_mv);
                Model::addViewObject($v);
            }
        }

        return 'view/appview.php';
    }


    function rozdeleniDV()
    {
        return new Redirect(null,  '?menuid=rozdelenidv&idpp=' . (int)$_POST['osoba'] . '&obdobi=' . $_POST['obdobi']);
    }


    function rozdeleniMV()
    {
        return new Redirect(null,  '?menuid=rozdelenimv&idpp=' . (int)$_POST['osoba'] . '&obdobi=' . $_POST['obdobi']);
    }


    function rozdeleniVyroby()
    {
        return new Redirect(null,  '?menuid=vyrobaosoby&osoba=' . (int)$_POST['osoba'] . '&obdobi=' . $_POST['obdobi']);
    }


    function prirazeniKalendare()
    {
        return new Redirect(null,  '?menuid=kalendarosoby&action=detailkalendare&osoba=' . (int)$_POST['osoba']);
    }


    function zpracujPost()
    {
        $b = new ZpracovanaDochazkaBrowser($this ->database);

        $pocatekObodbi = DateUtils::urlStringToDate($_POST['obdobi']);
        $obdobi = Obdobi::vratObdobi($this ->database, 'ADS', $pocatekObodbi);
        Prava::nastavObdobiProPrava($obdobi ->zacatek, $obdobi ->konec);

        // nejdrive nacte puvodni data
        $b ->nactiDataZpracovane($_POST['osoba'], $obdobi);

        try {
            if (!$b->nactiPost()) {
                // chyba v zadanych datech, napr. spatny format
                $b ->loadFilterData();
                return $this->zobrazZpracovanou($b);
            }

            $b->zpracujPost();

            if (isset($_POST['rozdelenidv']) && $_POST['rozdelenidv']) {
                return $this->rozdeleniDV();
            }

            if (isset($_POST['rozdelenimv']) && $_POST['rozdelenimv']) {
                return $this->rozdeleniMV();
            }

            if (isset($_POST['rozdelenivyroby']) && $_POST['rozdelenivyroby']) {
                return $this->rozdeleniVyroby();
            }

            if (isset($_POST['kalendarosoby']) && $_POST['kalendarosoby']) {
                return $this->prirazeniKalendare();
            }

            $params = '';

            if (isset($_POST['dialogschvaleni']) && $_POST['dialogschvaleni'] && !$b->denniVysledky->jeChyba) {
                $params .= '&dialogschvaleni';
            } else if (isset($_POST['vlozitdokument']) && $_POST['vlozitdokument']) {
                $params .= '&vlozitdokument';
            } else {
                if (isset($_POST['x']) && (int)$_POST['x']) {
                    $params .= '&x=' . (int)$_POST['x'];
                }
                if (isset($_POST['y']) && (int)$_POST['y']) {
                    $params .= '&y=' . (int)$_POST['y'];
                }
            }

            require_once 'xml/xmlformportal.php';
            return RonPortalXMLForm::$eventRedirect ?: new Redirect(null, '?menuid=zpracovanadochazka&idpp=' . (int)$_POST['osoba'] . '&obdobi=' . $_POST['obdobi'] . $params);
        } catch (\Exception $e) {
            MessageManager::addErrorMessage($e);
        }

        $b ->loadFilterData();
        return $this->zobrazZpracovanou($b);
    }


    function zpracovanaDochazkaBrowser()
    {
        if (isset($_POST['zpracovana_dochazka']) && $_POST['zpracovana_dochazka']) {
            return $this ->zpracujPost();
        }

        $b = new ZpracovanaDochazkaBrowser($this ->database);
        $b->load();

        return $this ->zobrazZpracovanou($b);
    }


    public function report()
    {
        $obdobi = Obdobi::vratObdobi($this ->database, 'ADS', DateUtils::urlStringToDate($_GET['obdobi'], true));
        Prava::nastavObdobiProPrava($obdobi ->zacatek, $obdobi ->konec);

        $pp = new PracovniPomer();
        if ( !$pp ->nactiPPPodleId($this ->database, $_GET['idpp']) ) {
            throw new \Exception('Nelze nacist zadanou osobu!');
        };

        $prava = Prava::vratPrava('prohlizeni');
        if (!$prava ->lzeZobrazitPP($pp ->idPP, $obdobi ->zacatek, $obdobi ->konec)) {
            throw new NeniPravoException();
        }

        //$result = new XmlReportOutputObject($report, $format)

        $result = new ReportOutputObject();
        $result->loadReportFromGet($this ->database, 'ZpracovanaDochazka', false, 'ZpracovanaDochazka'); // z duvodu kompatibility nacita i reporty zacinajici "ZpracovanaDochazka"
        $result ->nastavObdobi(0, $obdobi ->zacatek, $obdobi ->konec, $obdobi ->popis);
        $result ->nastavPP($pp);
        //$result->dateParams = 'IdSluzebniCesty=' . $_GET['idslcesty'];

        return $result;

    }


    /**
     * @param JsonOutputObject $output
     * @throws \Exception
     */
    function nactiSmenyPK($output)
    {
        // parametry: idpp=...&obdobi=...&dny=j.n.Y;j.n.Y;...
        $dnyStrA = explode(';', $_GET['dny']); // seznam dnu, pro ktere se ma zmena provest
        if (!$dnyStrA) throw new \Exception('Chyba - neni zadan datum (parametr dny)!');
        $dny = [];
        foreach ($dnyStrA as $denStr) {
            if ($denStr) {
                $dny[] = DateUtils::urlStringToDate($denStr);
            }
        }

        $datum = $dny[0];

        // nacte osobu a zkontroluje pravo
        $pp = PracovniPomer::nactiPP($this ->database, (int)$_GET['idpp']);
        Prava::nastavObdobiProPrava($datum, $datum);
        if (!Prava::lzeZobrazitPP('prohlizeni', $pp ->idPP, $datum, $datum)) {
            throw new NeniPravoException();
        }

        $output->addData('datum', date('j.n.Y', $datum));

        $rezimUprav = false; // TODO: urcit automaticky podle toho jestli uz je plan schvalen?
        // zjisti kalendar osoby
        $kalendar = PrirazeniKalendare::nactiKalendarProDen($this ->database, $pp ->idPP, $datum);

        if (!$kalendar) {
            throw new \Exception('Chyba - zamestnanec nema prirazen kalendar!');
        }
        $output ->addText('kalendar', $kalendar ->kod);
        $output ->addText('popisKalendare', $kalendar ->popis);

        // nacte naplanovanou smenu
        $smena = PlanovaniKapacit_PlanovanaSmena::nactiDataProDetail($this->database, $datum, $pp->rc, $pp->osobniCislo, $pp->datumNastupu, $rezimUprav);
        $obj = $smena->getJSON(true); // detail = true
        $output->addData('planovanaSmena', $obj);

        $seznamSmen = null;
        switch (RonPortalSettings::getIntValue('kapacity_povolitsmenypodledne')) {
            case 1 :
                // smeny povolene v kalendari
                $seznamSmen = Smena::nactiSmenyKalendare($this ->database, $kalendar ->kod);
                break;

            case 2 :
                // smeny podle dne
                $seznamSmen = Smena::nactiSmenyKalendare($this ->database, $kalendar ->kod, $datum);
                break;

            default :
                // vsechny existujici smeny
                $seznamSmen = Smena::nactiSmeny($this ->database, 'Aktivni = 1', $this ->database->createParameters());
                break;
        }

        $smenyJson = [];
        foreach ($seznamSmen as $smena) {
            $smenyJson[] = $smena ->getJson();
        }
        $output->addData('smeny', $smenyJson);



       // PlanovaniKapacit::SETTINGS_SMENY_PODLE_DNE

    }


    /**
     * @param JsonOutputObject $output
     * @throws \Exception
     */
    function zapisSmenuPK($output)
    {
        $idpp = (int)$_GET['idpp'];
        $dnyStrA = explode(';', $_GET['dny']); // seznam dnu, pro ktere se ma zmena provest
        if (!$dnyStrA) throw new \Exception('Chyba - neni zadan datum (parametr dny)!');
        $dny = [];
        foreach ($dnyStrA as $denStr) {
            if ($denStr) {
                $dny[] = DateUtils::urlStringToDate($denStr);
            }
        }

        if (!$dny) return;

        $pp = PracovniPomer::nactiPP($this ->database, (int)$idpp);

        $rezimUprav = false; // TODO: urcit automaticky podle toho jestli uz je plan schvalen?

        Prava::nastavObdobiProPrava($dny[0]);

        TextManager::getInstance() ->loadStrings('kapacity.ini');

        foreach ($dny as $datum) {
            if ($_GET['smena'] === '') {
                KapacityUtils::zkontrolujSchvaleni($this ->database, $pp, $datum, $rezimUprav);

                $rec = new PlanovaniKapacitRecord($this->database, $pp, $this);
                $rec->logInfoMessage = 'Smazani naplanovane smeny pro den ' . date('j.n.Y', $datum);
                $rec->smazNaplanovaneSmeny($datum, $datum, $rezimUprav);
            } else {
                KapacityUtils::zapisPlanovanouSmenu($this->database, $pp, $datum, $datum, $_GET['smena'], $rezimUprav, null, $this);
            }

            if (RonPortalSettings::getSpousteniADS()  &&  (int)$_GET['prepocitat']) {
                $params = '8 ' .  // uloha - podle puvodni
                    ' -interval:' . date('Y-n-j', $datum) . ';' . date('Y-n-j', $datum) .
                    ' -IDPP:' . $pp ->idPP;

                AgentManager::executeADS('ADS_Agent_Processing.exe', $params );
            }
        }
    }


    function nastavSirkuGraficke()
    {
        $newWidth = (int)$_GET['newWidth'];
        NastaveniUzivatele::setUserSettingsItem($this ->database, 'editace_graficka_width', (int)$newWidth, 300);
    }


    /**
     * @param string $action
     * @param JsonOutputObject $output
     */
    function handleJsonAction($action, $output)
    {
        switch ($_GET['action']) {
            case 'smenypk' :
                $this ->nactiSmenyPK($output);
                break;

            case 'zapissmenupk' :
                $this ->zapisSmenuPK($output);
                break;

            case 'grafickawidth' :
                $this ->nastavSirkuGraficke();
                break;
        }
    }


    public function handleAction($action)
    {
        if (isset($_GET['action'])) {
            switch ($_GET['action']) {
                case 'report' :
                    return $this ->report();

                case 'smenypk' :
                case 'zapissmenupk' :
                case 'grafickawidth' :
                    return parent::handleAction($action);
            }
        }

        TextManager::getInstance() ->loadStrings('dochazka.ini');
        HtmlHeaders::getInstance() ->addScript('script/dochazka.js');
        HtmlHeaders::getInstance() ->addCss('css/dochazka.css');
        HtmlHeaders::getInstance() ->setTitle( \Ron\ronText('RON_Portal') . ' - ' . \Ron\ronText('Dochazka_title'));

        return $this ->zpracovanaDochazkaBrowser();
    }

}


return new ZpracovanaDochazkaController($this ->database);

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/controllers/zpracovanadochazka.php <==
<?php
/**
 * stanislav.elbl, 21.04.2016
 */

namespace RonPortal\Editace;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\BlockViewObject;
use Ron\MVC\JsonController;
use Ron\MVC\JsonOutputObject;
use Ron\MVC\Model;
use Ron\MVC\Redirect;
use Ron\TextManager;
use Ron\XmlLoader;
use RonPortal\Dochazka\MesicniVysledkyBrowser;
use RonPortal\Dochazka\MesicniVysledkyBrowser1;
use RonPortal\Dochazka\PrirazeniKalendare;
use RonPortal\Dochazka\SchvaleniDochazky;
use RonPortal\Dochazka\Smena;
use RonPortal\Kapacity\KapacityUtils;
use RonPortal\Kapacity\PlanovaniKapacit_PlanovanaSmena;
use RonPortal\Kapacity\PlanovaniKapacitRecord;
use RonPortal\NastaveniUzivatele;
use RonPortal\NeniPravoException;
use RonPortal\Obdobi;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\RonPortalSettings;
use RonPortal\Security;
use RonPortal\System\AgentManager;
use RonPortal\System\ReportOutputObject;
use RonPortal\XML\RonPortalXMLForm;

class ZpracovanaDochazkaController extends JsonController
{
    const SETTINGS_ZOBRAZIT_MESICNI = 'mesicnivezpracovane'; // priznak, jestli se maji ve zpracovane zobrazit mesicni vysledky (standardni zobrazeni jako v mesicnich vysledcich)

    /** @var Database */
    public $database;

    /**
     * ZpracovanaDochazkaController constructor.
     * @param $database
     */
    public function __construct($database)
    {
        $this->database = $database;
    }


    /**
     * @param ZpracovanaDochazkaBrowser $b
     * @return string
     */
    function zobrazZpracovanou($b)
    {
        Model::addViewObject($b);

        if ($b->denniVysledky->pp && RonPortalSettings::getIntValue(self::SETTINGS_ZOBRAZIT_MESICNI)) {
            // zobrazi standardni needitovatelne mesicni vysledky
            if (RonPortalSettings::getIntValue(RonPortalSettings::MESICNI_VYSLEDKY_ZOBRAZIT) && RonPortalSettings::getValue(RonPortalSettings::MESICNI_VYSLEDKY_RADKY)) {
                $b_mv = new MesicniVysledkyBrowser($this->database, false);
                $b_mv->tableId = 'zpracovanadochazka_mv';
                $b_mv->showFilter = false;
                $b_mv->filterForm = $b->filterForm; // pro nacteni parametru (obdobi, pp)
                $b_mv->load();
                Model::addViewObject($b_mv);
            } else {
                $v = new BlockViewObject();
                $v->wrappingElementParams = 'id="zpracovanadochazka_mv"';

                $b_mv = new MesicniVysledkyBrowser1($this->database);
                $b_mv->showFilter = false;
                $b_mv->filterForm = $b->filterForm; // pro nacteni parametru (obdobi, pp)
                $b_mv->load();

                $v->addViewObject($b_mv);
                Model::addViewObject($v);
            }
        }

        return 'view/appview.php';
    }


    function rozdeleniDV()
    {
        return new Redirect(null, '?menuid=rozdelenidv&idpp=' . (int)$_POST['osoba'] . '&obdobi=' . $_POST['obdobi']);
    }


    function rozdeleniMV()
    {
        return new Redirect(null, '?menuid=rozdelenimv&idpp=' . (int)$_POST['osoba'] . '&obdobi=' . $_POST['obdobi']);
    }


    function rozdeleniVyroby()
    {
        return new Redirect(null, '?menuid=vyrobaosoby&osoba=' . (int)$_POST['osoba'] . '&obdobi=' . $_POST['obdobi']);
    }


    function prirazeniKalendare()
    {
        return new Redirect(null, '?menuid=kalendarosoby&action=detailkalendare&osoba=' . (int)$_POST['osoba']);
    }


    function podleKalendare($datumOd, $datumDo)
    {
        return new Redirect(null,
            '?menuid=podlekalendare&idpp=' . (int)$_POST['osoba'] .
            '&datum=' . DateUtils::dateToUrlString($datumOd) .
            '&datumdo=' . DateUtils::dateToUrlString($datumDo)
        );
    }


    function zpracujPost()
    {
        $b = new ZpracovanaDochazkaBrowser($this->database);

        $pocatekObodbi = DateUtils::urlStringToDate($_POST['obdobi']);
        $obdobi = Obdobi::vratObdobi($this->database, 'ADS', $pocatekObodbi);
        Prava::nastavObdobiProPrava($obdobi->zacatek, $obdobi->konec);

        // nejdrive nacte puvodni data
        $b->nactiDataZpracovane($_POST['osoba'], $obdobi);

        try {
            if (!$b->nactiPost()) {
                // chyba v zadanych datech, napr. spatny format
                $b->loadFilterData();
                return $this->zobrazZpracovanou($b);
            }

            $b->zpracujPost();

            if (isset($_POST['rozdelenidv']) && $_POST['rozdelenidv']) {
                return $this->rozdeleniDV();
            }

            if (isset($_POST['rozdelenimv']) && $_POST['rozdelenimv']) {
                return $this->rozdeleniMV();
            }

            if (isset($_POST['rozdelenivyroby']) && $_POST['rozdelenivyroby']) {
                return $this->rozdeleniVyroby();
            }

            if (isset($_POST['kalendarosoby']) && $_POST['kalendarosoby']) {
                return $this->prirazeniKalendare();
            }

            if (isset($_POST['dialogpodlekalendare'])  &&  $_POST['dialogpodlekalendare']) {
                $datumOd = $b ->denniVysledky ->schvaleni ->prvniEditovatelnyDen(
                    $b ->denniVysledky ->pp ->idPP,
                    $b ->denniVysledky ->datumOd, $b ->denniVysledky ->datumDo);

                if ($datumOd) {
                    $datumDo = $b ->denniVysledky ->datumDo;
                    if ($b ->denniVysledky ->dochazkaZpracovanaDo < $datumDo) {
                        $datumDo = $b ->denniVysledky ->dochazkaZpracovanaDo;
                    }
                    return $this->podleKalendare($datumOd, $datumDo);
                } else {
                    MessageManager::addErrorMessage('Dochazka_je_jiz_schvalena');
                }
            }

            $params = '';

            if (isset($_POST['dialogschvaleni']) && $_POST['dialogschvaleni'] && !$b->denniVysledky->jeChyba) {
                $params .= '&dialogschvaleni';
            } else if (isset($_POST['vlozitdokument']) && $_POST['vlozitdokument']) {
                $params .= '&vlozitdokument';
            } else {
                if (isset($_POST['x']) && (int)$_POST['x']) {
                    $params .= '&x=' . (int)$_POST['x'];
                }
                if (isset($_POST['y']) && (int)$_POST['y']) {
                    $params .= '&y=' . (int)$_POST['y'];
                }
            }

            return RonPortalXMLForm::$eventRedirect ?: new Redirect(null, '?menuid=zpracovanadochazka&idpp=' . (int)$_POST['osoba'] . '&obdobi=' . $_POST['obdobi'] . $params);
        } catch (\Exception $e) {
            MessageManager::addErrorMessage($e);
        }

        $b->loadFilterData();
        return $this->zobrazZpracovanou($b);
    }


    private function kopieDne()
    {
        try {
            $datum = DateUtils::dateStringToTimestamp($_POST['datum']);
            Prava::nastavObdobiProPrava($datum, $datum);

            $pp = PracovniPomer::nactiPP($this->database, (int)$_POST['osoba']);
            if (!Prava::lzeZobrazitPP('editace', $pp->idPP, $datum)) {
                throw new NeniPravoException();
            }

            $obdobi = Obdobi::vratObdobi($this->database, 'ADS', $datum);
            if ($obdobi->uzavreno) {
                throw new \Exception('Obdobi_uzavreno');
            }

            Security::validateCSRFPostParam();

            $datumOd = DateUtils::dateStringToTimestamp($_POST['datumOd']);
            $datumDo = DateUtils::dateStringToTimestamp($_POST['datumDo']);

            // Datum od - do musi byt ve stejnem obdobi
            if ($datumOd < $obdobi->zacatek || $datumDo > $obdobi->konec) {
                throw new \Exception('Spatne zadany rozsah datumu - cilove dny musi byt ve stejnem obdobi jako kopirovany den!');
            }

            $schvaleni = SchvaleniDochazky::nactiSchvaleni($this->database, $pp, $obdobi->zacatek);
            if (!$schvaleni->lzeEditovatPP($pp->idPP, $datumOd)) {
                throw new \Exception(sprintf(TextManager::_('Nelze_editovat_den_dochazka_schvalena'), date('j.n.Y', $datumOd)));
            }

            EditaceDneUtils::zkopirujDenDochazky($this->database,
                $pp, $datum, $datumOd, $datumDo, $this,
                [
                    'pouzePrazdneDny' => isset($_POST['pouzePrazdneDny']) ? (int)$_POST['pouzePrazdneDny'] : false,
                    'pouzeDnySeSmenou' => isset($_POST['pouzeDnySeSmenou']) ? (int)$_POST['pouzeDnySeSmenou'] : false
                ]);

            // z nastaveni zpracovane dochazky zjisti, jestli se maji vkladat prestavky
            $vkladatPrestavky = false;

            $settingsStr = RonPortalSettings::getBvarSettings($this->database, 'RonPortal_Nastaveni_zpracovane', null);
            if ($settingsStr) {
                $settings = XmlLoader::loadXmlToArray($settingsStr);
                $vkladatPrestavky = $settings['#attr']['vkladatprestavky'] == '1';
            }

            AgentManager::prepocetDochazky(
                $pp->idPP,
                $datumOd, $datumDo, // DateUtils::lastDayOfMonth($datumOd),
                $vkladatPrestavky);

            if (RonPortalXMLForm::$eventRedirect) {
                return RonPortalXMLForm::$eventRedirect;
            }
        } catch (\Exception $e) {
            MessageManager::addErrorMessage($e);
        }

        return new Redirect(null, '?menuid=zpracovanadochazka&idpp=' . (int)$_POST['osoba'] . '&obdobi=' . $_POST['obdobi']);
    }


    function zpracovanaDochazkaBrowser()
    {
        if (isset($_POST['zpracovana_dochazka']) && $_POST['zpracovana_dochazka']) {
            return $this ->zpracujPost();
        }

        try {
            if (isset($_POST['kopieDne'])  &&  $_POST['kopieDne']) {
                return $this ->kopieDne();
            }
        } catch (\Exception $e) {
            MessageManager::addErrorMessage($e);
        }

        $b = new ZpracovanaDochazkaBrowser($this ->database);
        $b->load();

        return $this ->zobrazZpracovanou($b);
    }


    public function report()
    {
        $obdobi = Obdobi::vratObdobi($this ->database, 'ADS', DateUtils::urlStringToDate($_GET['obdobi'], true));
        Prava::nastavObdobiProPrava($obdobi ->zacatek, $obdobi ->konec);

        $pp = new PracovniPomer();
        if ( !$pp ->nactiPPPodleId($this ->database, $_GET['idpp']) ) {
            throw new \Exception('Nelze nacist zadanou osobu!');
        };

        $prava = Prava::vratPrava('prohlizeni');
        if (!$prava ->lzeZobrazitPP($pp ->idPP, $obdobi ->zacatek, $obdobi ->konec)) {
            throw new NeniPravoException();
        }

        //$result = new XmlReportOutputObject($report, $format)

        $result = new ReportOutputObject();
        $result->loadReportFromGet($this ->database, 'ZpracovanaDochazka', false, 'ZpracovanaDochazka'); // z duvodu kompatibility nacita i reporty zacinajici "ZpracovanaDochazka"
        $result ->nastavObdobi(0, $obdobi ->zacatek, $obdobi ->konec, $obdobi ->popis);
        $result ->nastavPP($pp);
        //$result->dateParams = 'IdSluzebniCesty=' . $_GET['idslcesty'];

        return $result;

    }


    /**
     * @param JsonOutputObject $output
     * @throws \Exception
     */
    function nactiSmenyPK($output)
    {
        // parametry: idpp=...&obdobi=...&dny=j.n.Y;j.n.Y;...
        $dnyStrA = explode(';', $_GET['dny']); // seznam dnu, pro ktere se ma zmena provest
        if (!$dnyStrA) throw new \Exception('Chyba - neni zadan datum (parametr dny)!');
        $dny = [];
        foreach ($dnyStrA as $denStr) {
            if ($denStr) {
                $dny[] = DateUtils::urlStringToDate($denStr);
            }
        }

        $datum = $dny[0];

        // nacte osobu a zkontroluje pravo
        $pp = PracovniPomer::nactiPP($this ->database, (int)$_GET['idpp']);
        Prava::nastavObdobiProPrava($datum, $datum);
        if (!Prava::lzeZobrazitPP('prohlizeni', $pp ->idPP, $datum, $datum)) {
            throw new NeniPravoException();
        }

        $output->addData('datum', date('j.n.Y', $datum));

        $rezimUprav = false; // TODO: urcit automaticky podle toho jestli uz je plan schvalen?
        // zjisti kalendar osoby
        $kalendar = PrirazeniKalendare::nactiKalendarProDen($this ->database, $pp ->idPP, $datum);

        if (!$kalendar) {
            throw new \Exception('Chyba - zamestnanec nema prirazen kalendar!');
        }
        $output ->addText('kalendar', $kalendar ->kod);
        $output ->addText('popisKalendare', $kalendar ->popis);

        // nacte naplanovanou smenu
        $smena = PlanovaniKapacit_PlanovanaSmena::nactiDataProDetail($this->database, $datum, $pp->rc, $pp->osobniCislo, $pp->datumNastupu, $rezimUprav);
        $obj = $smena->getJSON(true); // detail = true
        $output->addData('planovanaSmena', $obj);

        $seznamSmen = null;
        switch (RonPortalSettings::getIntValue('kapacity_povolitsmenypodledne')) {
            case 1 :
                // smeny povolene v kalendari
                $seznamSmen = Smena::nactiSmenyKalendare($this ->database, $kalendar ->kod);
                break;

            case 2 :
                // smeny podle dne
                $seznamSmen = Smena::nactiSmenyKalendare($this ->database, $kalendar ->kod, $datum);
                break;

            default :
                // vsechny existujici smeny
                $seznamSmen = Smena::nactiSmeny($this ->database, 'Aktivni = 1', $this ->database->createParameters());
                break;
        }

        $smenyJson = [];
        foreach ($seznamSmen as $smena) {
            $smenyJson[] = $smena ->getJson();
        }
        $output->addData('smeny', $smenyJson);



       // PlanovaniKapacit::SETTINGS_SMENY_PODLE_DNE

    }


    /**
     * @param JsonOutputObject $output
     * @throws \Exception
     */
    function zapisSmenuPK($output)
    {
        $idpp = (int)$_GET['idpp'];
        $dnyStrA = explode(';', $_GET['dny']); // seznam dnu, pro ktere se ma zmena provest
        if (!$dnyStrA) throw new \Exception('Chyba - neni zadan datum (parametr dny)!');
        $dny = [];
        foreach ($dnyStrA as $denStr) {
            if ($denStr) {
                $dny[] = DateUtils::urlStringToDate($denStr);
            }
        }

        if (!$dny) return;

        $pp = PracovniPomer::nactiPP($this ->database, (int)$idpp);

        $rezimUprav = false; // TODO: urcit automaticky podle toho jestli uz je plan schvalen?

        Prava::nastavObdobiProPrava($dny[0]);

        TextManager::getInstance() ->loadStrings('kapacity.ini');

        foreach ($dny as $datum) {
            if ($_GET['smena'] === '') {
                KapacityUtils::zkontrolujSchvaleni($this ->database, $pp, $datum, $rezimUprav);

                $rec = new PlanovaniKapacitRecord($this->database, $pp, $this);
                $rec->logInfoMessage = 'Smazani naplanovane smeny pro den ' . date('j.n.Y', $datum);
                $rec->smazNaplanovaneSmeny($datum, $datum, $rezimUprav);
            } else {
                KapacityUtils::zapisPlanovanouSmenu($this->database, $pp, $datum, $datum, $_GET['smena'], $rezimUprav, null, $this);
            }

            if (RonPortalSettings::getSpousteniADS()  &&  (int)$_GET['prepocitat']) {
                $params = '8 ' .  // uloha - podle puvodni
                    ' -interval:' . date('Y-n-j', $datum) . ';' . date('Y-n-j', $datum) .
                    ' -IDPP:' . $pp ->idPP;

                AgentManager::executeADS('ADS_Agent_Processing.exe', $params );
            }
        }
    }


    function nastavSirkuGraficke()
    {
        $newWidth = (int)$_GET['newWidth'];
        NastaveniUzivatele::setUserSettingsItem($this ->database, 'editace_graficka_width', (int)$newWidth, 300);
    }


    /**
     * @param string $action
     * @param JsonOutputObject $output
     */
    function handleJsonAction($action, $output)
    {
        switch ($_GET['action']) {
            case 'smenypk' :
                $this ->nactiSmenyPK($output);
                break;

            case 'zapissmenupk' :
                $this ->zapisSmenuPK($output);
                break;

            case 'grafickawidth' :
                $this ->nastavSirkuGraficke();
                break;
        }
    }


    public function handleAction($action)
    {
        if (isset($_GET['action'])) {
            switch ($_GET['action']) {
                case 'report' :
                    return $this ->report();

                case 'smenypk' :
                case 'zapissmenupk' :
                case 'grafickawidth' :
                    return parent::handleAction($action);
            }
        }

        TextManager::getInstance()
            ->loadStrings('dochazka.ini');

        HtmlHeaders::getInstance()
            ->addScript('script/dochazka.js')
            ->addCss('css/dochazka.css')
            ->setTitle( \Ron\ronText('RON_Portal') . ' - ' . \Ron\ronText('Dochazka_title'));

        return $this ->zpracovanaDochazkaBrowser();
    }

}


return new ZpracovanaDochazkaController($this ->database);
